@@ -1,7 +1,6 @@
 package main
 
 import (
-	"encoding/json"
 	"fmt"
 	"io"
 	"os"
@@ -72,34 +71,31 @@ func paramIDMapping() (*types.IDMappingOptions, error) {
 	return &options, nil
 }
 
-func createLayer(flags *mflag.FlagSet, action string, m storage.Store, args []string) int {
+func createLayer(flags *mflag.FlagSet, action string, m storage.Store, args []string) (int, error) {
 	parent := ""
 	if len(args) > 0 {
 		parent = args[0]
 	}
 	mappings, err := paramIDMapping()
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "%v\n", err)
-		return 1
+		return 1, err
 	}
 	options := &storage.LayerOptions{IDMappingOptions: *mappings}
 	layer, err := m.CreateLayer(paramID, parent, paramNames, paramMountLabel, !paramCreateRO, options)
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "%+v\n", err)
-		return 1
+		return 1, err
 	}
 	if jsonOutput {
-		json.NewEncoder(os.Stdout).Encode(layer)
-	} else {
-		fmt.Printf("%s\n", layer.ID)
-		for _, name := range layer.Names {
-			fmt.Printf("\t%s\n", name)
-		}
+		return outputJSON(layer)
 	}
-	return 0
+	fmt.Printf("%s\n", layer.ID)
+	for _, name := range layer.Names {
+		fmt.Printf("\t%s\n", name)
+	}
+	return 0, nil
 }
 
-func importLayer(flags *mflag.FlagSet, action string, m storage.Store, args []string) int {
+func importLayer(flags *mflag.FlagSet, action string, m storage.Store, args []string) (int, error) {
 	parent := ""
 	if len(args) > 0 {
 		parent = args[0]
@@ -108,45 +104,39 @@ func importLayer(flags *mflag.FlagSet, action string, m storage.Store, args []st
 	if applyDiffFile != "" {
 		f, err := os.Open(applyDiffFile)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, "%v\n", err)
-			return 1
+			return 1, err
 		}
 		diffStream = f
 		defer f.Close()
 	}
 	mappings, err := paramIDMapping()
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "%v\n", err)
-		return 1
+		return 1, err
 	}
 	options := &storage.LayerOptions{IDMappingOptions: *mappings}
 	layer, _, err := m.PutLayer(paramID, parent, paramNames, paramMountLabel, !paramCreateRO, options, diffStream)
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "%+v\n", err)
-		return 1
+		return 1, err
 	}
 	if jsonOutput {
-		json.NewEncoder(os.Stdout).Encode(layer)
-	} else {
-		fmt.Printf("%s\n", layer.ID)
-		for _, name := range layer.Names {
-			fmt.Printf("\t%s\n", name)
-		}
+		return outputJSON(layer)
 	}
-	return 0
+	fmt.Printf("%s\n", layer.ID)
+	for _, name := range layer.Names {
+		fmt.Printf("\t%s\n", name)
+	}
+	return 0, nil
 }
 
-func createImage(flags *mflag.FlagSet, action string, m storage.Store, args []string) int {
+func createImage(flags *mflag.FlagSet, action string, m storage.Store, args []string) (int, error) {
 	if paramMetadataFile != "" {
 		f, err := os.Open(paramMetadataFile)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, "%v\n", err)
-			return 1
+			return 1, err
 		}
 		b, err := io.ReadAll(f)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, "%v\n", err)
-			return 1
+			return 1, err
 		}
 		paramMetadata = string(b)
 	}
@@ -159,55 +149,48 @@ func createImage(flags *mflag.FlagSet, action string, m storage.Store, args []st
 	}
 	image, err := m.CreateImage(paramID, paramNames, layer, paramMetadata, imageOptions)
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "%+v\n", err)
-		return 1
+		return 1, err
 	}
 	if jsonOutput {
-		json.NewEncoder(os.Stdout).Encode(image)
-	} else {
-		fmt.Printf("%s\n", image.ID)
-		for _, name := range image.Names {
-			fmt.Printf("\t%s\n", name)
-		}
+		return outputJSON(image)
 	}
-	return 0
+	fmt.Printf("%s\n", image.ID)
+	for _, name := range image.Names {
+		fmt.Printf("\t%s\n", name)
+	}
+	return 0, nil
 }
 
-func createContainer(flags *mflag.FlagSet, action string, m storage.Store, args []string) int {
+func createContainer(flags *mflag.FlagSet, action string, m storage.Store, args []string) (int, error) {
 	if paramMetadataFile != "" {
 		f, err := os.Open(paramMetadataFile)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, "%v\n", err)
-			return 1
+			return 1, err
 		}
 		b, err := io.ReadAll(f)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, "%v\n", err)
-			return 1
+			return 1, err
 		}
 		paramMetadata = string(b)
 	}
 	mappings, err := paramIDMapping()
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "%v\n", err)
-		return 1
+		return 1, err
 	}
 	options := &storage.ContainerOptions{IDMappingOptions: *mappings, Volatile: paramVolatile}
 	image := args[0]
 	container, err := m.CreateContainer(paramID, paramNames, image, paramLayer, paramMetadata, options)
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "%+v\n", err)
-		return 1
+		return 1, err
 	}
 	if jsonOutput {
-		json.NewEncoder(os.Stdout).Encode(container)
-	} else {
-		fmt.Printf("%s\n", container.ID)
-		for _, name := range container.Names {
-			fmt.Printf("\t%s", name)
-		}
+		return outputJSON(container)
 	}
-	return 0
+	fmt.Printf("%s\n", container.ID)
+	for _, name := range container.Names {
+		fmt.Printf("\t%s", name)
+	}
+	return 0, nil
 }
 
 func init() {
